@@ -15,15 +15,15 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 8
+#define ARROW_VERSION_MAJOR 9
 #define ARROW_VERSION_MINOR 0
-#define ARROW_VERSION_PATCH 1
+#define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "8.0.1"
+#define ARROW_VERSION_STRING "9.0.0"
 
-#define ARROW_SO_VERSION "800"
-#define ARROW_FULL_SO_VERSION "800.1.0"
+#define ARROW_SO_VERSION "900"
+#define ARROW_FULL_SO_VERSION "900.0.0"
 
 #define ARROW_CXX_COMPILER_ID "Clang"
 #define ARROW_CXX_COMPILER_VERSION "14.0.6"
@@ -43,8 +43,11 @@
 #define ARROW_FILESYSTEM
 #define ARROW_FLIGHT
 #define ARROW_IPC
+#define ARROW_JEMALLOC
+#define ARROW_JEMALLOC_VENDORED
 #define ARROW_JSON
 
+/* #undef ARROW_GCS */
 /* #undef ARROW_S3 */
 #define ARROW_USE_NATIVE_INT128
 /* #undef ARROW_WITH_OPENTELEMETRY */
